@@ -40,9 +40,9 @@ namespace MailTransport
   class SocketPrivate
   {
     public:
-      SocketPrivate( Socket* s);
-      Socket* const       q;
-      QSslSocket*         socket;
+      SocketPrivate( Socket *s );
+      Socket             *const q;
+      QSslSocket         *socket;
       QString             server;
       QString             protocol;
       int                 port;
@@ -53,23 +53,25 @@ namespace MailTransport
       void slotStateChanged( QAbstractSocket::SocketState state );
       void slotModeChanged( QSslSocket::SslMode  state );
       void slotSocketRead();
-      void slotSslErrors( const QList<QSslError> & errors );
+      void slotSslErrors( const QList<QSslError> &errors );
+    private:
+      QString m_msg;
   };
 }
 
-SocketPrivate::SocketPrivate( Socket* s) : q(s)
+SocketPrivate::SocketPrivate( Socket *s ) : q( s )
 {
 }
 
 void SocketPrivate::slotConnected()
 {
-  kDebug( 5324 ) ;
+  kDebug() ;
 
   if ( !secure ) {
-    kDebug( 5324 ) << "normal connect";
+    kDebug() << "normal connect";
     emit q->connected();
   } else {
-    kDebug( 5324 ) << "encrypted connect";
+    kDebug() << "encrypted connect";
     socket->startClientEncryption();
   }
 }
@@ -77,82 +79,86 @@ void SocketPrivate::slotConnected()
 void SocketPrivate::slotStateChanged( QAbstractSocket::SocketState state )
 {
 #ifdef comm_debug
-  kDebug( 5324 ) << q->objectName() << "State is now:" << ( int ) state;
+  kDebug() << "State is now:" << ( int ) state;
 #endif
-  if ( state == QAbstractSocket::UnconnectedState )
+  if ( state == QAbstractSocket::UnconnectedState ) {
     emit q->failed();
+  }
 }
 
 void SocketPrivate::slotModeChanged( QSslSocket::SslMode  state )
 {
 #ifdef comm_debug
-  kDebug( 5324 ) << q->objectName() << "Mode is now:" << state;
+  kDebug() << "Mode is now:" << state;
 #endif
+  if ( state == QSslSocket::SslClientMode ) {
+    emit q->tlsDone();
+  }
 }
 
 void SocketPrivate::slotSocketRead()
 {
-  kDebug(5324) << q->objectName();
+  kDebug();
 
-  if ( !socket )
+  if ( !socket ) {
     return;
+  }
 
-  static QString msg;
-  msg += QLatin1String( socket->readAll() );
+  m_msg += QLatin1String( socket->readAll() );
 
-  if ( !msg.endsWith( QLatin1Char( '\n' ) ) )
+  if ( !m_msg.endsWith( QLatin1Char( '\n' ) ) ) {
     return;
+  }
 
 #ifdef comm_debug
-  kDebug( 5324 ) << q->objectName() << socket->isEncrypted() << msg.trimmed();
+  kDebug() << socket->isEncrypted() << m_msg.trimmed();
 #endif
 
-  emit q->data( msg );
-  msg.clear();
+  emit q->data( m_msg );
+  m_msg.clear();
 }
 
 void SocketPrivate::slotSslErrors( const QList<QSslError> & )
 {
-  kDebug( 5324 ) ;
+  kDebug();
   /* We can safely ignore the errors, we are only interested in the
   capabilities. We're not sending auth info. */
   socket->ignoreSslErrors();
   emit q->connected();
 }
 
-
 // ------------------ end private ---------------------------//
 
-Socket::Socket( QObject* parent )
+Socket::Socket( QObject *parent )
     : QObject( parent ), d( new SocketPrivate( this ) )
 {
   d->socket = 0;
   d->port = 0;
   d->secure = false;
-  kDebug( 5324 ) ;
+  kDebug();
 }
 
 Socket::~Socket()
 {
-  kDebug( 5324 ) << objectName() ;
+  kDebug();
   delete d;
 }
 
 void Socket::reconnect()
 {
-  kDebug( 5324 ) << objectName() << "Connecting to:" << d->server
-          <<  ":" <<  d->port;
+  kDebug() << "Connecting to:" << d->server <<  ":" <<  d->port;
 
 #ifdef comm_debug
-  // kDebug(5324) << objectName() << d->protocol;
+  // kDebug() << d->protocol;
 #endif
 
-  if ( d->socket )
+  if ( d->socket ) {
     return;
+  }
 
-  d->socket = static_cast<QSslSocket*>
-             ( KSocketFactory::connectToHost( d->protocol, d->server, d->port, this
-                                            ) );
+  d->socket =
+    static_cast<QSslSocket *>( KSocketFactory::connectToHost( d->protocol, d->server,
+                                                              d->port, this ) );
 
   d->socket->setProtocol( QSsl::AnyProtocol );
 
@@ -167,18 +173,19 @@ void Socket::reconnect()
            SLOT( slotSslErrors( const QList<QSslError>& ) ) );
 }
 
-void Socket::write( const QString& text )
+void Socket::write( const QString &text )
 {
-  // kDebug(5324) << objectName() ;
+  // kDebug();
   // Eat things in the queue when there is no connection. We need
   // to get a connection first don't we...
-  if ( !d->socket || !available() )
+  if ( !d->socket || !available() ) {
     return;
+  }
 
   QByteArray cs = ( text + QLatin1String( "\r\n" ) ).toLatin1();
 
 #ifdef comm_debug
-  kDebug( 5324 ) << objectName() << "C   :" << cs;
+  kDebug() << "C   :" << cs;
 #endif
 
   d->socket->write( cs.data(), cs.size() );
@@ -186,21 +193,28 @@ void Socket::write( const QString& text )
 
 bool Socket::available()
 {
-  // kDebug(5324) << objectName() ;
+  // kDebug();
   bool ok = d->socket && d->socket->state() == QAbstractSocket::ConnectedState;
   return ok;
 }
 
-void Socket::setProtocol( const QString& proto )
+void Socket::startTLS()
+{
+  kDebug() << objectName();
+  d->socket->setProtocol( QSsl::TlsV1 );
+  d->socket->startClientEncryption();
+}
+
+void Socket::setProtocol( const QString &proto )
 {
   d->protocol = proto;
 }
 
-void Socket::setServer( const QString& server )
+void Socket::setServer( const QString &server )
 {
   d->server = server;
 }
-      
+
 void Socket::setPort( int port )
 {
   d->port = port;
