@@ -10,17 +10,17 @@
 #ifndef SYNDICATION_DATARETRIEVER_H
 #define SYNDICATION_DATARETRIEVER_H
 
-#include "ksyndication.h"
+#include "ksyndication_export.h"
 
 #include <QtCore/QObject>
 #include <QtCore/QString>
+#include <QtCore/QProcess>
 
 namespace KIO
 {
     class Job;
 }
 class KJob;
-class KProcess;
 class KUrl;
 
 class QByteArray;
@@ -133,8 +133,7 @@ class SYNDICATION_EXPORT OutputRetriever : public DataRetriever
         virtual void abort() {}
 
     private Q_SLOTS:
-        void slotOutput(KProcess* process, char* data, int length);
-        void slotExited(KProcess* process);
+        void slotFinished ( int exitCode, QProcess::ExitStatus exitStatus ) ;
 
     private:
         OutputRetriever(const OutputRetriever& other);
